@@ -1,2 +1,2 @@
-from .CellautomatBinary import CellAutomatBinary
+from .CellAutomatBinary import CellAutomatBinary
 from .CellAutomatRegression import CellAutomatRegression
\ No newline at end of file
